# SPIFFY
 Space Interferometer Python Framework
 A collection of tools to visualize, calculate and simulate GW spatial interferometers.
 
 ## How does it work
 
 This library integrates the following Python libraries:
 - Sympy: uses the Vector and ReferenceFrame utilities. In the future may use CAS.
 - Numpy: number crunching and used by mayavi.
 - Mayavi: 3d visualization of orbits.
 - Matplotlib: other useful visualizations.
 
 Plus the theoretical framework of:
 - Orbital mechanics;
 - Gravitational wave signals;
 - Time-Delay Interferometry.
 
 
 
 ## Installation
 
 See `requirements.txt` for a list of requirements. Some are not straightfoward to install and may required additional tools (such as VS toolkit).
 
 ## Using:
 
 At the time, only circular orbits are defined.
